pub struct Scancode { /* private fields */ }Expand description
A raw scancode emitted by a keyboard.
Can be constructed from raw integers via From<u8>, From<u16> and From<u32>.
Each KeymapEntry maps a scancode to an evdev key code.
The Scancode belonging to an entry can be fetched with KeymapEntry::scancode.
The Scancode type is also used when modifying the keymap using the
Evdev::set_keymap_entry and Evdev::set_keymap_entry_by_index functions.